pub fn reset_pipeline_dispatch_buckets()Expand description
Reset the per-pipeline dispatch buckets (typically called at decode start to ignore prefill / warmup contributions).
pub fn reset_pipeline_dispatch_buckets()Reset the per-pipeline dispatch buckets (typically called at decode start to ignore prefill / warmup contributions).