pub fn register(registry: &mut KernelRegistry)Expand description
Register flash attention vector shader source with the given kernel registry.
pub fn register(registry: &mut KernelRegistry)Register flash attention vector shader source with the given kernel registry.