clear_rope_pack_cache

Function clear_rope_pack_cache 

pub fn clear_rope_pack_cache()
Clear the thread-local rope-multi pack cache.

Useful between model loads (the cache key includes the device pointer so old entries can never be returned for a new device, but they leak memory until cleared) and in test suites that swap mocked devices.